@@ -12,3 +12,7 @@ class PaginationException(ERPException):
     def __init__(self, msg: str):
         super().__init__('0000-E001',
                          f'Erro nos parâmetros requisitados para paginação: {msg}')
+
+
+class NotFoundException(Exception):
+    pass
